@@ -41,6 +41,10 @@ class Base:
         self._jwt_header = {
             'Authorization': f'Bearer {token}'
         }
+        _res = requests.get(f"{base_discovery_api}/api/v2/account/me/", headers=self._jwt_header)
+        if _res.status_code != 200:
+            txt = _res.json() if _res.status_code < 500 else " "
+            raise Exception(f"Can not connect to DataPlatform, {txt}")
         self.token = token
         self._tmp_path = 'dsm.tmp'
         os.makedirs(self._tmp_path, exist_ok=True)
@@ -51,9 +55,30 @@ class Base:
         self._minio_access = data['access']
         self._minio_secret = data['secret']
         
+        # self.client = Minio(
+        #     base_minio_url,
+        #     access_key=self._minio_access,
+        #     secret_key=self._minio_secret,
+        #     secure=True
+        # )
+        # self._storage_options = {
+        #     'key': self._minio_access,
+        #     'secret': self._minio_secret,
+        #     'client_kwargs':{
+        #         'endpoint_url': minio_url
+        #     }
+        # }
         self.client = Minio(
-            base_minio_url,
+            "192.168.24.207:9000",
             access_key=self._minio_access,
             secret_key=self._minio_secret,
-            secure=True
-        )
\ No newline at end of file
+            secure=False
+        )
+        
+        self._storage_options = {
+            'key': self._minio_access,
+            'secret': self._minio_secret,
+            'client_kwargs':{
+                'endpoint_url': "http://192.168.24.207:9000"
+            }
+        }
\ No newline at end of file
