@@ -6,22 +6,22 @@ from tqdm.utils import CallbackIOWrapper
 from .base import discovery_api, Base
 class DatasetManager(Base):
 
-    def upload_file(self, directory=None, file_path=None, description=""):
+    def upload_file(self, directory_id=None, file_path=None, description=""):
         if type(file_path) != str :
             raise Exception(f"file_path expect `str` but got {type(file_path)}, or please input `file_path='<path>'`")
         elif not os.path.exists(file_path):
             raise Exception(f"file {os.path.abspath(file_path)} not found")
-        if directory == None:
+        if directory_id == None:
              raise Exception("please input directory, like `directory=<id>`")
-        _res = requests.get(f"{discovery_api}/directory/{directory}",  headers=self._jwt_header)
+        _res = requests.get(f"{discovery_api}/directory/{directory_id}",  headers=self._jwt_header)
         if _res.status_code == 404:
-            raise Exception(f"directory {directory} not found or your dose not has permission to access directory")
+            raise Exception(f"directory {directory_id} not found or your dose not has permission to access directory")
         f_name = os.path.basename(file_path)
         _res = requests.post(f"{discovery_api}/file/", headers=self._jwt_header,
                              data={
                                  'name': f_name,
                                  'description': f_name,
-                                 'directory': int(directory),
+                                 'directory': int(directory_id),
                                  'size': os.path.getsize(file_path),
                                  'is_use': True
                              }
@@ -47,7 +47,7 @@ class DatasetManager(Base):
         })
         return data
     
-    def download_file(self, file_id=None):
+    def download_file(self, file_id=None, download_path=None):
         if file_id == None:
              raise Exception("please input file_id")
         _res = requests.get(f"{discovery_api}/file/{file_id}/",  headers=self._jwt_header)
@@ -60,6 +60,12 @@ class DatasetManager(Base):
         
         _res = requests.get(_res.json()['url'])
         f_path = os.path.join(self._tmp_path, meta['name'])
+        if download_path != None:
+            if (not os.path.exists(download_path)) or (not os.path.isdir(download_path)):
+                raise Exception("`download_path` is not existx or is not directory")
+            else:
+                f_path = os.path.join(self._tmp_path, meta['name'])
+            
         
         total_size_in_bytes= int(_res.headers.get('content-length', 0))
         print(total_size_in_bytes)
